@@ -31,7 +31,7 @@ def render(source_path, build_path):
                 % source_path)
         pass
     template = Environment.from_string(settings.JINJA_ENV, contents)
-    out = template.render()
+    out = template.render(ROOT=settings.ROOT)
     # save it
     fp = open(build_path, 'w')
     fp.write(out)
