@@ -9,7 +9,9 @@ from jinja2 import Environment, FileSystemLoader, Template
 EXCLUDED = (
     '_build',
     'layout.html',
-    '.DS_Store'
+    '.DS_Store',
+    'conf.py',
+    'conf.pyc',
 )
 # which extentions to renderr?
 EXTENTIONS = (
@@ -22,10 +24,12 @@ FILTERS = (
    'pygmentize',
    'markdown',
 )
-# the jinja environment
+# the root for urls and paths - forward slash essential
+ROOT = '/'
 JINJA_ENV = Environment( loader=FileSystemLoader('.'))
 # overwrite the defaults from local conf
 try:
     from conf import *
-except ImportError:
+except ImportError, e:
+    print e
     pass
